Struct Cr3
#[repr(transparent)]pub struct Cr3(pub u32);Expand description
CR3 register.
Tuple Fields
0: u32Implementations
impl Cr3
impl Cr3
pub const fn ewu0(&self) -> bool
pub const fn ewu0(&self) -> bool
EWU0 Enable WakeUp line 0 (PB0) When this bit is set the wakeup line 0 is enabled and a rising or falling edge on wakeup line 0 will trigger a CPU wakeup event depending on CR4.WP0 bit.
pub fn set_ewu0(&mut self, val: bool)
pub fn set_ewu0(&mut self, val: bool)
EWU0 Enable WakeUp line 0 (PB0) When this bit is set the wakeup line 0 is enabled and a rising or falling edge on wakeup line 0 will trigger a CPU wakeup event depending on CR4.WP0 bit.
pub const fn ewu1(&self) -> bool
pub const fn ewu1(&self) -> bool
EWU1 Enable WakeUp line 1 (PB1) When this bit is set the wakeup line 1 is enabled and a rising or falling edge on wakeup line 1 will trigger a CPU wakeup event depending on CR4.WP1 bit.
pub fn set_ewu1(&mut self, val: bool)
pub fn set_ewu1(&mut self, val: bool)
EWU1 Enable WakeUp line 1 (PB1) When this bit is set the wakeup line 1 is enabled and a rising or falling edge on wakeup line 1 will trigger a CPU wakeup event depending on CR4.WP1 bit.
pub const fn ewu2(&self) -> bool
pub const fn ewu2(&self) -> bool
EWU2 Enable WakeUp line 2 (PB2) When this bit is set the wakeup line 2 is enabled and a rising or falling edge on wakeup line 2 will trigger a CPU wakeup event depending on CR4.WP2 bit.
pub fn set_ewu2(&mut self, val: bool)
pub fn set_ewu2(&mut self, val: bool)
EWU2 Enable WakeUp line 2 (PB2) When this bit is set the wakeup line 2 is enabled and a rising or falling edge on wakeup line 2 will trigger a CPU wakeup event depending on CR4.WP2 bit.
pub const fn ewu3(&self) -> bool
pub const fn ewu3(&self) -> bool
EWU3 Enable WakeUp line 3 (PB3) When this bit is set the wakeup line 3 is enabled and a rising or falling edge on wakeup line 3 will trigger a CPU wakeup event depending on CR4.WP3 bit.
pub fn set_ewu3(&mut self, val: bool)
pub fn set_ewu3(&mut self, val: bool)
EWU3 Enable WakeUp line 3 (PB3) When this bit is set the wakeup line 3 is enabled and a rising or falling edge on wakeup line 3 will trigger a CPU wakeup event depending on CR4.WP3 bit.
pub const fn ewu4(&self) -> bool
pub const fn ewu4(&self) -> bool
EWU4 Enable WakeUp line 4 (PB4) When this bit is set the wakeup line 4 is enabled and a rising or falling edge on wakeup line 4 will trigger a CPU wakeup event depending on CR4.WP4 bit.
pub fn set_ewu4(&mut self, val: bool)
pub fn set_ewu4(&mut self, val: bool)
EWU4 Enable WakeUp line 4 (PB4) When this bit is set the wakeup line 4 is enabled and a rising or falling edge on wakeup line 4 will trigger a CPU wakeup event depending on CR4.WP4 bit.
pub const fn ewu5(&self) -> bool
pub const fn ewu5(&self) -> bool
EWU5 Enable WakeUp line 5 (PB5) When this bit is set the wakeup line 5 is enabled and a rising or falling edge on wakeup line 5 will trigger a CPU wakeup event depending on CR4.WP5 bit.
pub fn set_ewu5(&mut self, val: bool)
pub fn set_ewu5(&mut self, val: bool)
EWU5 Enable WakeUp line 5 (PB5) When this bit is set the wakeup line 5 is enabled and a rising or falling edge on wakeup line 5 will trigger a CPU wakeup event depending on CR4.WP5 bit.
pub const fn ewu6(&self) -> bool
pub const fn ewu6(&self) -> bool
EWU6 Enable WakeUp line 6 (PB6) When this bit is set the wakeup line 6 is enabled and a rising or falling edge on wakeup line 6 will trigger a CPU wakeup event depending on CR4.WP6 bit.
pub fn set_ewu6(&mut self, val: bool)
pub fn set_ewu6(&mut self, val: bool)
EWU6 Enable WakeUp line 6 (PB6) When this bit is set the wakeup line 6 is enabled and a rising or falling edge on wakeup line 6 will trigger a CPU wakeup event depending on CR4.WP6 bit.
pub const fn ewu7(&self) -> bool
pub const fn ewu7(&self) -> bool
EWU7 Enable WakeUp line 7 (PB7) When this bit is set the wakeup line 7 is enabled and a rising or falling edge on wakeup line 7 will trigger a CPU wakeup event depending on CR4.WP7 bit.
pub fn set_ewu7(&mut self, val: bool)
pub fn set_ewu7(&mut self, val: bool)
EWU7 Enable WakeUp line 7 (PB7) When this bit is set the wakeup line 7 is enabled and a rising or falling edge on wakeup line 7 will trigger a CPU wakeup event depending on CR4.WP7 bit.
pub const fn ewu8(&self) -> bool
pub const fn ewu8(&self) -> bool
EWU8 Enable WakeUp line 8 (PA8) When this bit is set the wakeup line 8 is enabled and a rising or falling edge on wakeup line 8 will trigger a CPU wakeup event depending on CR4.WP8 bit.
pub fn set_ewu8(&mut self, val: bool)
pub fn set_ewu8(&mut self, val: bool)
EWU8 Enable WakeUp line 8 (PA8) When this bit is set the wakeup line 8 is enabled and a rising or falling edge on wakeup line 8 will trigger a CPU wakeup event depending on CR4.WP8 bit.
pub const fn ewu9(&self) -> bool
pub const fn ewu9(&self) -> bool
EWU9 Enable WakeUp line 9 (PA9) When this bit is set the wakeup line 9 is enabled and a rising or falling edge on wakeup line 9 will trigger a CPU wakeup event depending on CR4.WP9 bit.
pub fn set_ewu9(&mut self, val: bool)
pub fn set_ewu9(&mut self, val: bool)
EWU9 Enable WakeUp line 9 (PA9) When this bit is set the wakeup line 9 is enabled and a rising or falling edge on wakeup line 9 will trigger a CPU wakeup event depending on CR4.WP9 bit.
pub const fn ewu10(&self) -> bool
pub const fn ewu10(&self) -> bool
EWU10 Enable WakeUp line 10 (PA10) When this bit is set the wakeup line 10 is enabled and a rising or falling edge on wakeup line 10 will trigger a CPU wakeup event depending on CR4.WP10 bit.
pub fn set_ewu10(&mut self, val: bool)
pub fn set_ewu10(&mut self, val: bool)
EWU10 Enable WakeUp line 10 (PA10) When this bit is set the wakeup line 10 is enabled and a rising or falling edge on wakeup line 10 will trigger a CPU wakeup event depending on CR4.WP10 bit.
pub const fn ewu11(&self) -> bool
pub const fn ewu11(&self) -> bool
EWU11 Enable WakeUp line 11 (PA11) When this bit is set the wakeup line 11 is enabled and a rising or falling edge on wakeup line 11 will trigger a CPU wakeup event depending on CR4.WP11 bit.
pub fn set_ewu11(&mut self, val: bool)
pub fn set_ewu11(&mut self, val: bool)
EWU11 Enable WakeUp line 11 (PA11) When this bit is set the wakeup line 11 is enabled and a rising or falling edge on wakeup line 11 will trigger a CPU wakeup event depending on CR4.WP11 bit.
pub const fn ewble(&self) -> bool
pub const fn ewble(&self) -> bool
EWBLE: Enable wakeup on BLE event. 0: Wakeup on BLE line is disabled (default). 1: Wakeup on BLE line is enabled.
pub fn set_ewble(&mut self, val: bool)
pub fn set_ewble(&mut self, val: bool)
EWBLE: Enable wakeup on BLE event. 0: Wakeup on BLE line is disabled (default). 1: Wakeup on BLE line is enabled.
pub const fn ewblehcpu(&self) -> bool
pub const fn ewblehcpu(&self) -> bool
EWBLEHCPU: Enable wakeup on BLE Host CPU event. 0: Wakeup on BLE Host CPU line is disabled (default). 1: Wakeup on BLE Host CPU line is enabled.
pub fn set_ewblehcpu(&mut self, val: bool)
pub fn set_ewblehcpu(&mut self, val: bool)
EWBLEHCPU: Enable wakeup on BLE Host CPU event. 0: Wakeup on BLE Host CPU line is disabled (default). 1: Wakeup on BLE Host CPU line is enabled.
pub const fn eiwl2(&self) -> bool
pub const fn eiwl2(&self) -> bool
EIWL2: Enable wakeup on Internal event (LPUART). 0: Wakeup on internal line is disabled (default). 1: Wakeup on internal line is enabled.
pub fn set_eiwl2(&mut self, val: bool)
pub fn set_eiwl2(&mut self, val: bool)
EIWL2: Enable wakeup on Internal event (LPUART). 0: Wakeup on internal line is disabled (default). 1: Wakeup on internal line is enabled.