Struct Cr6
#[repr(transparent)]pub struct Cr6(pub u32);Expand description
CR6 register.
Tuple Fields
0: u32Implementations
impl Cr6
impl Cr6
pub const fn ewu12(&self) -> bool
pub const fn ewu12(&self) -> bool
EWU12 Enable WakeUp line 12 (PA0) When this bit is set the wakeup line 12 is enabled and a rising or falling edge on wakeup line 0 will trigger a CPU wakeup event depending on CR7.WP0 bit.
pub fn set_ewu12(&mut self, val: bool)
pub fn set_ewu12(&mut self, val: bool)
EWU12 Enable WakeUp line 12 (PA0) When this bit is set the wakeup line 12 is enabled and a rising or falling edge on wakeup line 0 will trigger a CPU wakeup event depending on CR7.WP0 bit.
pub const fn ewu13(&self) -> bool
pub const fn ewu13(&self) -> bool
EWU13 Enable WakeUp line 13 (PA1) When this bit is set the wakeup line 13 is enabled and a rising or falling edge on wakeup line 1 will trigger a CPU wakeup event depending on CR7.WP1 bit.
pub fn set_ewu13(&mut self, val: bool)
pub fn set_ewu13(&mut self, val: bool)
EWU13 Enable WakeUp line 13 (PA1) When this bit is set the wakeup line 13 is enabled and a rising or falling edge on wakeup line 1 will trigger a CPU wakeup event depending on CR7.WP1 bit.
pub const fn ewu14(&self) -> bool
pub const fn ewu14(&self) -> bool
EWU14 Enable WakeUp line 14 (PA2) When this bit is set the wakeup line 14 is enabled and a rising or falling edge on wakeup line 2 will trigger a CPU wakeup event depending on CR7.WP2 bit.
pub fn set_ewu14(&mut self, val: bool)
pub fn set_ewu14(&mut self, val: bool)
EWU14 Enable WakeUp line 14 (PA2) When this bit is set the wakeup line 14 is enabled and a rising or falling edge on wakeup line 2 will trigger a CPU wakeup event depending on CR7.WP2 bit.
pub const fn ewu15(&self) -> bool
pub const fn ewu15(&self) -> bool
EWU15 Enable WakeUp line 15 (PA3) When this bit is set the wakeup line 15 is enabled and a rising or falling edge on wakeup line 3 will trigger a CPU wakeup event depending on CR7.WP3 bit.
pub fn set_ewu15(&mut self, val: bool)
pub fn set_ewu15(&mut self, val: bool)
EWU15 Enable WakeUp line 15 (PA3) When this bit is set the wakeup line 15 is enabled and a rising or falling edge on wakeup line 3 will trigger a CPU wakeup event depending on CR7.WP3 bit.
pub const fn ewu16(&self) -> bool
pub const fn ewu16(&self) -> bool
EWU16 Enable WakeUp line 16 (PB12) When this bit is set the wakeup line 16 is enabled and a rising or falling edge on wakeup line 4 will trigger a CPU wakeup event depending on CR7.WP4 bit.
pub fn set_ewu16(&mut self, val: bool)
pub fn set_ewu16(&mut self, val: bool)
EWU16 Enable WakeUp line 16 (PB12) When this bit is set the wakeup line 16 is enabled and a rising or falling edge on wakeup line 4 will trigger a CPU wakeup event depending on CR7.WP4 bit.
pub const fn ewu17(&self) -> bool
pub const fn ewu17(&self) -> bool
EWU17 Enable WakeUp line 17 (PB13) When this bit is set the wakeup line 17 is enabled and a rising or falling edge on wakeup line 5 will trigger a CPU wakeup event depending on CR7.WP5 bit.
pub fn set_ewu17(&mut self, val: bool)
pub fn set_ewu17(&mut self, val: bool)
EWU17 Enable WakeUp line 17 (PB13) When this bit is set the wakeup line 17 is enabled and a rising or falling edge on wakeup line 5 will trigger a CPU wakeup event depending on CR7.WP5 bit.
pub const fn ewu18(&self) -> bool
pub const fn ewu18(&self) -> bool
EWU18 Enable WakeUp line 18 (PB14) When this bit is set the wakeup line 18 is enabled and a rising or falling edge on wakeup line 6 will trigger a CPU wakeup event depending on CR7.WP6 bit.
pub fn set_ewu18(&mut self, val: bool)
pub fn set_ewu18(&mut self, val: bool)
EWU18 Enable WakeUp line 18 (PB14) When this bit is set the wakeup line 18 is enabled and a rising or falling edge on wakeup line 6 will trigger a CPU wakeup event depending on CR7.WP6 bit.
pub const fn ewu19(&self) -> bool
pub const fn ewu19(&self) -> bool
EWU19 Enable WakeUp line 19 (PB15) When this bit is set the wakeup line 19 is enabled and a rising or falling edge on wakeup line 7 will trigger a CPU wakeup event depending on CR7.WP7 bit.