stm32-metapac

Crates

git

Versions

stm32wb06cc

Flavors

Extsrr

Struct Extsrr 

#[repr(transparent)]
pub struct Extsrr(pub u32);
EXTSRR register.

Tuple Fields

0: u32

Implementations



impl Extsrr

pub const fn deepstopf(&self) -> Deepstopf

DEEPSTOPF System DeepStop Flag This bit is set by hardware and cleared only by a POR reset or by writing ‘1’ in this bit field.

pub fn set_deepstopf(&mut self, val: Deepstopf)

DEEPSTOPF System DeepStop Flag This bit is set by hardware and cleared only by a POR reset or by writing ‘1’ in this bit field.

pub const fn rfphasef(&self) -> Rfphasef

RFPHASEF RFPHASE Flag This bit is set by hardware after a Radio wake-up event (BLE activation); it is cleared either by software, writing ‘1’ in this bit field, or by hardware when Ready2Sleep signal is asserted by the Radio IP.

pub fn set_rfphasef(&mut self, val: Rfphasef)

RFPHASEF RFPHASE Flag This bit is set by hardware after a Radio wake-up event (BLE activation); it is cleared either by software, writing ‘1’ in this bit field, or by hardware when Ready2Sleep signal is asserted by the Radio IP.