stm32-metapac

Crates

git

Versions

stm32wb06cc

Flavors

Sr3

Struct Sr3 

#[repr(transparent)]
pub struct Sr3(pub u32);
SR3 register.

Tuple Fields

0: u32

Implementations



impl Sr3

pub const fn wuf12(&self) -> Wuf

WUF12 WakeUp Flag 12 PA0 This bit is set when a wakeup is detected on wakeup line 12. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub fn set_wuf12(&mut self, val: Wuf)

WUF12 WakeUp Flag 12 PA0 This bit is set when a wakeup is detected on wakeup line 12. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub const fn wuf13(&self) -> Wuf

WUF13 WakeUp Flag 13 PA1 This bit is set when a wakeup is detected on wakeup line 13. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub fn set_wuf13(&mut self, val: Wuf)

WUF13 WakeUp Flag 13 PA1 This bit is set when a wakeup is detected on wakeup line 13. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub const fn wuf14(&self) -> Wuf

WUF14 WakeUp Flag 14 PA2 This bit is set when a wakeup is detected on wakeup line 14. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub fn set_wuf14(&mut self, val: Wuf)

WUF14 WakeUp Flag 14 PA2 This bit is set when a wakeup is detected on wakeup line 14. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub const fn wuf15(&self) -> Wuf

WUF15 WakeUp Flag 15 PA3 This bit is set when a wakeup is detected on wakeup line 15. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub fn set_wuf15(&mut self, val: Wuf)

WUF15 WakeUp Flag 15 PA3 This bit is set when a wakeup is detected on wakeup line 15. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub const fn wuf16(&self) -> Wuf

WUF16 WakeUp Flag 16 PB12 This bit is set when a wakeup is detected on wakeup line 16. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub fn set_wuf16(&mut self, val: Wuf)

WUF16 WakeUp Flag 16 PB12 This bit is set when a wakeup is detected on wakeup line 16. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub const fn wuf17(&self) -> Wuf

WUF17 WakeUp Flag 17 PB13 This bit is set when a wakeup is detected on wakeup line 17. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub fn set_wuf17(&mut self, val: Wuf)

WUF17 WakeUp Flag 17 PB13 This bit is set when a wakeup is detected on wakeup line 17. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub const fn wuf18(&self) -> Wuf

WUF18 WakeUp Flag 18 PB14 This bit is set when a wakeup is detected on wakeup line 18. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub fn set_wuf18(&mut self, val: Wuf)

WUF18 WakeUp Flag 18 PB14 This bit is set when a wakeup is detected on wakeup line 18. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub const fn wuf19(&self) -> Wuf

WUF19 WakeUp Flag 19 PB15 This bit is set when a wakeup is detected on wakeup line 19. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub fn set_wuf19(&mut self, val: Wuf)

WUF19 WakeUp Flag 19 PB15 This bit is set when a wakeup is detected on wakeup line 19. It is cleared by a reset pad or by writing 1 in this bit field. writting this bit, clears the interrupt:.

pub const fn wuf20(&self) -> bool

PB8 I/O wake-up flag.

pub fn set_wuf20(&mut self, val: bool)

PB8 I/O wake-up flag.

pub const fn wuf21(&self) -> bool

PB9 I/O wake-up flag.

pub fn set_wuf21(&mut self, val: bool)

PB9 I/O wake-up flag.

pub const fn wuf22(&self) -> bool

PB10 I/O wake-up flag.

pub fn set_wuf22(&mut self, val: bool)

PB10 I/O wake-up flag.

pub const fn wuf23(&self) -> bool

PB11 I/O wake-up flag.

pub fn set_wuf23(&mut self, val: bool)

PB11 I/O wake-up flag.

pub const fn wuf24(&self) -> bool

PB12 I/O wake-up flag.

pub fn set_wuf24(&mut self, val: bool)

PB12 I/O wake-up flag.

pub const fn wuf25(&self) -> bool

PB13 I/O wake-up flag.

pub fn set_wuf25(&mut self, val: bool)

PB13 I/O wake-up flag.

pub const fn wuf26(&self) -> bool

PB14 I/O wake-up flag.

pub fn set_wuf26(&mut self, val: bool)

PB14 I/O wake-up flag.

pub const fn wuf27(&self) -> bool

PB15 I/O wake-up flag.

pub fn set_wuf27(&mut self, val: bool)

PB15 I/O wake-up flag.